@@ -1,5 +1,6 @@
 .lambda <- list(symbols=c(".",".i",".name"))
 .nsymbol <- length(.lambda$symbols)
+.nfsymbol <- 2L + .nsymbol
 
 lambda <- function(expr) {
   .lambda$expr <- expr
@@ -11,34 +12,23 @@ lambda <- function(expr) {
     } else if(symbol == "~") {
       symbols <- expr[[2L]]
       .lambda$expr <- expr[[3L]]
-    } else {
-      return(.lambda)
-    }
-    if(is.name(symbols)) {
-      .lambda$symbols[1L] <- as.character(symbols)
-    } else if(is.call(symbols)) {
+    } else return(.lambda)
+
+    if(is.name(symbols)) .lambda$symbols[1L] <- as.character(symbols)
+    else if(is.call(symbols)) {
       symbols <- as.character(as.list(symbols)[-1L])
       indices <- which(symbols != "")
       .lambda$symbols[indices] <- symbols[indices]
-    } else {
-      stop("Invalid lambda expression")
-    }
+    } else stop("Invalid lambda expression")
   }
   .lambda
 }
 
-lambda.env <- function(envir) {
-  new.env(FALSE,envir)
-}
-
-list.env <- function(x) {
-  if(is.list(x) || is.environment(x)) {
-    x
-  } else if(is.vector(x) && !is.null(names(x))) {
-    as.vector(x,"list")
-  } else {
-    NULL
-  }
+#' @export
+.list.env <- function(x) {
+  if(is.list(x) || is.environment(x)) x
+  else if(is.vector(x) && !is.null(names(x))) as.vector(x,"list")
+  else NULL
 }
 
 dots <- function(...) {
@@ -49,15 +39,7 @@ list.sort.functions <- list(desc=`-`)
 
 setnames <- `names<-`
 
-unname <- function(x) {
-  setnames(x,NULL)
-}
-
-unit <- function(x) x
-
-getnames <- function(x,null=character(length(x))) {
-  if(is.null(names(x))) null else names(x)
-}
+getnames <- function(x,null=NULL) if(is.null(names(x))) null else names(x)
 
 set_argnames <- function(args,data=args) {
   argnames <- names(args)
