@@ -14,5 +14,5 @@
 #' list.all(x,mean(unlist(score))>=6)
 #' }
 list.all <- function(.data,cond,na.rm=FALSE) {
-  all(list.if.internal(.data,substitute(cond),FALSE),na.rm = na.rm)
+  all(list.if.internal(.data,substitute(cond)),na.rm = na.rm)
 }
