@@ -1,7 +1,8 @@
 #' Classify list members into unique cases evaluated by given expression.
 #'
-#' @param .data The list to be classified
-#' @param expr An expression that determines cases
+#' @param .data \code{list}
+#' @param expr A lambda expression
+#' @param ... Additional parameters passed to \code{unique}
 #' @param sort.cases \code{logical}. if \code{TRUE} the cases will be sorted in ascending order.
 #' @name list.class
 #' @export
@@ -21,10 +22,9 @@
 #' list.class(x,interest)
 #' list.class(x,names(lang))
 #' }
-list.class <- function(.data,expr,sort.cases=TRUE) {
-  expr <- substitute(expr)
-  values <- list.map.internal(.data,expr)
-  cases <- unique(unlist(values,use.names = FALSE))
+list.class <- function(.data,expr,...,sort.cases=TRUE) {
+  values <- list.map.internal(.data,substitute(expr))
+  cases <- unique(unlist(values,use.names = FALSE),...)
   names(cases) <- cases
   if(sort.cases)  cases <- sort(cases)
   lapply(cases,function(case) {
