@@ -15,7 +15,7 @@
 list.load <- function(file,type=tolower(tools::file_ext(file)),...) {
   fun <- paste("list.load",type,sep = ".")
   if(existsFunction(fun)) {
-    fun <- get(fun)
+    fun <- get(fun,mode = "function")
     fun(file,...)
   } else {
     list.load.rdata(file,...)
